==> brobygger-li-2.3.2.tar.gz: brobygger-li-2.3.2/scraper/linkedin/mutual_connections/schemas.py <==
"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/10/20
"""
# Standard library imports
from typing import Optional, List

# Related third party imports
from pydantic import BaseModel, Field

# Import local applications
from scraper.general_schemas import InitModel, ExtraModel


# noinspection PyMissingOrEmptyDocstring
class MutualConnectionsModel(BaseModel):
    full_name: Optional[str] = Field(...)
    dist_value: Optional[str] = Field(...)
    headline: Optional[str] = Field(...)
    location: Optional[str] = Field(...)
    url: str = Field(...)
    # mutual_connections_url: Optional[str] = Field(...,
    #                                               title="Mutual connections",
    #                                               description='Link to mutual connections'
    #                                               )
    # mutual_connections: Optional[List[str]] = Field(...,
    #                                               title="Mutual connections",
    #                                               description=' mutual connections'
    #                                               )
    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "full_name": "full_name",
            "dist_value": "dist_value",
            "headline": "headline",
            'location': 'location',
            "url": "url"
            # "mutual_connections_url": "mutual_connections_url",
            # "mutual_connections": "mutual_connections"
        }
        allow_population_by_field_name = True


class MutualConnectionsSchema(BaseModel):
    """
    Mutual Connections schema
    """
    init: InitModel = Field(...)
    extra: ExtraModel = Field(...)
    mutual_connections: List[MutualConnectionsModel] = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Mutual Connections'
        fields = {
            'init': 'init',
            'extra':'extra',
            'mutual_connections': 'mutual_connections'
        }
        allow_population_by_field_name = True

==> brobygger-li-2.5.1.tar.gz: brobygger-li-2.5.1/scraper/linkedin/mutual_connections/schemas.py <==
"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/10/20
"""
# Standard library imports
from typing import Optional, List

# Related third party imports
from pydantic import BaseModel, Field

# Import local applications
from scraper.general_schemas import InitModel, ExtraModel


# noinspection PyMissingOrEmptyDocstring
class MutualConnectionsModel(BaseModel):
    full_name: Optional[str] = Field(...)
    dist_value: Optional[str] = Field(...)
    headline: Optional[str] = Field(...)
    location: Optional[str] = Field(...)
    url: str = Field(...)
    premium: Optional[bool] = Field(...)
    mutual_connections_url: Optional[str] = Field(...,
                                                  title="Mutual connections",
                                                  description='Link to mutual connections'
                                                  )
    mutual_connections: Optional[str] = Field(...,
                                                  title="Mutual connections",
                                                  description=' mutual connections'
                                                  )
    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "full_name": "full_name",
            "dist_value": "dist_value",
            "headline": "headline",
            'location': 'location',
            "url": "url",
            "premium": "premium",
            "mutual_connections_url": "mutual_connections_url",
            "mutual_connections": "mutual_connections"
        }
        allow_population_by_field_name = True


class MutualConnectionsSchema(BaseModel):
    """
    Mutual Connections schema
    """
    init: InitModel = Field(...)
    extra: ExtraModel = Field(...)
    mutual_connections: List[MutualConnectionsModel] = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Mutual Connections'
        fields = {
            'init': 'init',
            'extra':'extra',
            'mutual_connections': 'mutual_connections'
        }
        allow_population_by_field_name = True
